The auth namespace provides an interface to simplify communicating with the
NuID Auth API. You will need an API Key
from the NuID Developer Portal in order
to make authenticated calls to the Auth API.
NOTE: You will need to configure this HTTP client with your API Key. See
merge-opts! for configuration instructions.
The `auth` namespace provides an interface to simplify communicating with the [NuID Auth API](https://portal.nuid.io/docs/api). You will need an API Key from the [NuID Developer Portal](https://portal.nuid.io/guides/intro) in order to make authenticated calls to the Auth API. NOTE: You will need to configure this HTTP client with your API Key. See [[merge-opts!]] for configuration instructions.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |